==> haskell-fsnotify-0.4.4.0-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.4.0
visibility:           public
id:                   fsnotify-0.4.4.0-5p3EciNBWmhC5LIKFzDp2N
key:                  fsnotify-0.4.4.0-5p3EciNBWmhC5LIKFzDp2N
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  6aa575445d5b22e84d44c2e84ce2811c
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.4.0-5p3EciNBWmhC5LIKFzDp2N
depends:
    async-2.2.5-DWviBtrYTc7K8qRxzPsJC base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    hinotify-0.4.2-6lVajRlknCD2HvpICNDeLs
    monad-control-1.0.3.1-GptxzQqshh7J2Y4ewMk2Hl
    safe-exceptions-0.1.7.4-JJtencRNvfPAVPHD6bpNCc text-2.0.2
    time-1.12.2 unix-2.7.3 unix-compat-0.7.4.1-E7DsEjXAuRTILEPpVPaZJi

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.4.4.0-24-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.4.0
visibility:           public
id:                   fsnotify-0.4.4.0-9wFlfAooPpJ2BdLnfX1lxU
key:                  fsnotify-0.4.4.0-9wFlfAooPpJ2BdLnfX1lxU
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  ffd42a325a10b01ebf369c1112b5b6c0
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.4.0-9wFlfAooPpJ2BdLnfX1lxU
depends:
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-Bi6WhcL9fCKI2Q94FqV1ys
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs
    safe-exceptions-0.1.7.4-E2jhex6cl0w6t2rEagsyOt text-2.0.2
    time-1.12.2 unix-2.7.3 unix-compat-0.7.4.1-4GSEG4F7IBa3tepmzc9c8r

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
